from setuptools import setup, find_packages

setup(
    name="VidBarcodeSimilarities",
    version="0.0.1",
    description="A library to compare similarities between barcode images",
    author="Abdulsobur",
    author_email="Abdulsoburoyewale@gmail.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)
